@@ -1,7 +1,7 @@
 from upplib import *
 from upplib.clean_up_msg import *
 from datetime import datetime, timezone, timedelta
-from typing import Any, Optional, Union
+from typing import Any, Optional, Union, Callable, List
 
 
 def get_log_msg(contents: dict,
@@ -31,15 +31,7 @@ def get_log_msg(contents: dict,
         # content 中, 含有时间，是以时间开头的字符串
         if time_1 is not None and _time_ is not None:
             content = content[len(time_str):].strip()
-    return ' '.join(filter(lambda s: s is not None, [_time_, level, content]))
-
-
-def clean_up_msg(msg: str = None, clean_up_type: int = 1) -> str:
-    if msg is None:
-        return ''
-    if clean_up_type == 1:
-        return clean_up_msg_1(msg)
-    return msg
+    return ' '.join(filter(lambda s: s is not None, [_time_, level, content.encode('unicode_escape').decode('ascii')]))
 
 
 def get_from_txt(file_name: str = '_start_time_end_time_str.txt',
@@ -107,7 +99,7 @@ def get_trace_id_from_txt(file_name: str = 'a.txt',
             if trace_id_type == 1:
                 try:
                     if ' - ' in trace_id_line:
-                        trace_id = trace_id_line.split(' - ')[0].split(' ')[-1].strip()
+                        trace_id = trace_id_line[0:130].split(' - ')[0].split(' ')[-1].strip()
                         if 15 <= len(trace_id) <= 55 and len(trace_id.split('-')) >= 3:
                             trace_id_ids.add(trace_id)
                 except Exception as e:
